#ifndef GLCD_H
#define GLCD_H

/***********************************************
*             glcd.h
*
*
* Setup and external funct declares for glcd.c             
*
* Please Select/alter settings to match your setup
*
* NOTE: Parallel mode only currently supported 
* with this code.
***********************************************/


typedef unsigned char u08;



//**** PROCESSOR TYPE ****
// Should be auto defined by compiler
//#define __dsPIC30F__
//#define __dsPIC33F__
//#define __PIC24F__
//#define __PIC24H__



/* Include appropiarte header file for processor type */


#if defined(__PIC24F__)
 #include <p24fxxxx.h> 

#elif defined(__PIC24H__)
 #include <p24hxxxx.h> 

#elif defined(__dsPIC30F__)
 #include <p30fxxxx.h>

#elif defined(__dsPIC33F__)
 #include <p33fxxxx.h>

#else
 #error Processor type not defined!!
#endif


/* Include Bitmap header */
#include "glcd-bitmaps.h"


//**** CPU SPEED IN Hz (MIP Rating) ****
#define F_CPU 40000000    /* dsPIC33 and 24HJ Max speed */
//#define F_CPU 30000000  /* dsPIC30 Max Speed */
//#define F_CPU 16000000  /* PIC24FJ Max Speed */






//**** LCD 128x64 dots - E.G. Displaytech 64128G
#define LCD_ROWS		8           // 8 bit row x 8 row = 64 dots
#define LCD_COLS		128         // 1 bit colum x 128 = 128 Dots


//**** I/O Ports
#define DATA_OUT LATE
#define DATA_DIR TRISE
#define DATA_IN  PORTE


//**** I/O Command Port Bits
#define RD    LATFbits.LATF1   /* LCD E Pin */
#define WR    LATFbits.LATF0   /* LCD RW Pin */
#define RS    LATDbits.LATD7   /* LCD RS pin */
#define RESET LATDbits.LATD6   /* LCD Reset pin */
#define CS    LATDbits.LATD5   /* LCD Chip Select */
//#define PS    1     /* PS - Parallel/Serial sel - tied high in hardware */
#define MI    LATGbits.LATG6   /* Parallel Mode Pin - set/pull to */

#define T_RD    TRISFbits.TRISF1   /* LCD E Pin */
#define T_WR    TRISFbits.TRISF0   /* LCD RW Pin */
#define T_RS    TRISDbits.TRISD7   /* LCD RS pin */
#define T_RESET TRISDbits.TRISD6   /* LCD Reset pin */
#define T_CS    TRISDbits.TRISD5   /* LCD Chip Select */
//#define T_PS    1     /* PS - Parallel/Serial sel - tied high in hardware */
#define T_MI    TRISGbits.TRISG6   /* Parallel Mode Pin - set/pull to */



/* Functions */

extern void lcd_init_io(void);
extern void lcd_read_dram(unsigned char *dest);
extern void lcd_write_byte(u08 data);
extern void lcd_write_dram(unsigned char *source);
extern void lcd_set_pos(u08 row, u08 col);
extern void lcd_clear(void);
extern void lcd_reset_init(void);
extern void show_icon(unsigned char *bitmap, u08 w, u08 h, u08 x, u08 y, u08 mode);
u08 draw_point(u08 x, u08 y, u08 v);
extern void draw_line(u08 x1, u08 y1, u08 x2, u08 y2, u08 v);
extern void fill_rect(u08 left, u08 top, u08 right, u08 bottom, u08 v);
extern void draw_rectangle(u08 left, u08 top, u08 right, u08 bottom, u08 linestate, u08 fillstate);
extern void select_font( unsigned char *f, u08 w, u08 h );
extern void draw_text( u08 x, u08 y, unsigned char *text , u08 m );



#define LCD_DIR_READ  0xFF
#define LCD_DIR_WRITE 0x00

#define LCD_DELAY 		1

/* Display ON/OFF	001010111O
 * O 0=OFF 1=ON
 */
#define LCD_CMD_ON		0xAE

/* Initial display line ST5-0
 * Specify DDRAM line for COM1
 */
#define LCD_CMD_IDL		0x40

/* Set reference voltage mode 0010000001
 */
#define LCD_CMD_SRV		0x81

/* Set page address	001011DCBA
 * D-A P3-P1
 */
#define LCD_CMD_SPAGE		0xB0

/* Set column address 000001DCBA
 * D-A  Y7-4
 * next Y3-0			
 */
#define LCD_CMD_COL		0x10

/* ADC select 001010011A
 * A 0=normal direction 1=reverse horizontal
 */
#define LCD_CMD_ADC		0xA0

/* SHL select 001100SXXX
 * S 0=normal 1=reverse vertical
 */
#define LCD_CMD_SHL		0xC0

/* Reverse display ON/OFF 001010011R
 * R 0=normal 1=reverse
 */
#define	LCD_CMD_REVERSE		0xA6

/* Entire display ON/OFF 001010010E
 * E 0=normal 1=entire
 */
#define LCD_CMD_EON		0xA4

/* LCD bias select 001010001B
 * B Bias  
 */
#define LCD_CMD_BIAS		0xA2

/* Set modify-read 0011100000
 */
#define LCD_CMD_SMR		0xE0

/* Reset modify-read 0011101110
 */
#define LCD_CMD_RMR		0xEE

/* Reset 0011100010
 * Initialize the internal functions
 */
#define LCD_CMD_RESET		0xE2

/* Power control 0000101CRF
 * control power circuite operation
 */
#define LCD_CMD_POWERC		0x28

/* Regulator resistor select 0000100CBA
 * select internal resistor ration
 */
#define LCD_CMD_RES		0x20	// Regulator resistor select

/* Set static indicator 001010110S
 * S 0=off 1=on
 * next 00XXXXXXBC
 */
#define LCD_CMD_SIR		0xAC

/* Read Status 01BAOR0000
 * B BUSY
 * A ADC
 * O ON/OFF
 * R RESETB
 */
#define LCD_STAT_BUSY	0x80
#define LCD_STAT_ADC	0x40
#define LCD_STAT_ON		0x20
#define LCD_STAT_RESETB	0x10

#define LCD_POWERC_VC	0x04
#define LCD_POWERC_VR	0x02
#define LCD_POWERC_VF	0x01

#define LCD_PIXEL_OFF   0
#define LCD_PIXEL_ON    1
#define LCD_PIXEL_INV   2


#define DLY_COUNT  (F_CPU/2000000)

#define _delay_us( dly ) {unsigned int x=0,y=dly; while(y--){x=DLY_COUNT;while(x--);}}


#endif

